@@ -49,14 +49,14 @@ class ModelArgs:
     early_stopping_metric: str = "eval_loss"
     early_stopping_metric_minimize: bool = True
     early_stopping_patience: int = 3
-    encoding: str = None
+    encoding: str = "utf-8"
     eval_batch_size: int = 8
     evaluate_during_training: bool = False
     evaluate_during_training_silent: bool = True
     evaluate_during_training_steps: int = 2000
     evaluate_during_training_verbose: bool = False
     evaluate_each_epoch: bool = True
-    fp16: bool = True
+    fp16: bool = False
     gradient_accumulation_steps: int = 1
     learning_rate: float = 4e-5
     local_rank: int = -1
@@ -97,8 +97,8 @@ class ModelArgs:
     use_cached_eval_features: bool = False
     use_early_stopping: bool = False
     use_hf_datasets: bool = False
-    use_multiprocessing: bool = True
-    use_multiprocessing_for_evaluation: bool = True
+    use_multiprocessing: bool = False
+    use_multiprocessing_for_evaluation: bool = False
     wandb_kwargs: dict = field(default_factory=dict)
     wandb_project: str = None
     warmup_ratio: float = 0.06
@@ -179,7 +179,7 @@ class T5Args(ModelArgs):
     special_tokens_list: list = field(default_factory=list)
     top_k: float = None
     top_p: float = None
-    use_multiprocessed_decoding: bool = True
+    use_multiprocessed_decoding: bool = False
 
 
 @dataclass
@@ -218,7 +218,8 @@ class LanguageModelingArgs(ModelArgs):
             args_dict = self.get_args_for_saving()
             if args_dict["dataset_class"] is not None:
                 args_dict["dataset_class"] = type(args_dict["dataset_class"]).__name__
-            json.dump(self.get_args_for_saving(), f)
+            # json.dump(self.get_args_for_saving(), f)
+            json.dump(args_dict, f)
 
     def load(self, input_dir):
         if input_dir:
@@ -272,7 +273,7 @@ class Seq2SeqArgs(ModelArgs):
             args_dict = self.get_args_for_saving()
             if args_dict["dataset_class"] is not None:
                 args_dict["dataset_class"] = type(args_dict["dataset_class"]).__name__
-            json.dump(self.get_args_for_saving(), f)
+            json.dump(args_dict, f)
 
     def load(self, input_dir):
         if input_dir:
