@@ -337,29 +337,6 @@ def convert_example_to_feature(example_row):
             start_position = cls_index
             end_position = cls_index
 
-        # if example_index < 20:
-        #     logger.info("*** Example ***")
-        #     logger.info("unique_id: %s" % (unique_id))
-        #     logger.info("example_index: %s" % (example_index))
-        #     logger.info("doc_span_index: %s" % (doc_span_index))
-        #     logger.info("tokens: %s" % " ".join(tokens))
-        #     logger.info(
-        #         "token_to_orig_map: %s" % " ".join(["%d:%d" % (x, y) for (x, y) in token_to_orig_map.items()])
-        #     )
-        #     logger.info(
-        #         "token_is_max_context: %s"
-        #         % " ".join(["%d:%s" % (x, y) for (x, y) in token_is_max_context.items()])
-        #     )
-        #     logger.info("input_ids: %s" % " ".join([str(x) for x in input_ids]))
-        #     logger.info("input_mask: %s" % " ".join([str(x) for x in input_mask]))
-        #     logger.info("segment_ids: %s" % " ".join([str(x) for x in segment_ids]))
-        #     if is_training and span_is_impossible:
-        #         logger.info("impossible example")
-        #     if is_training and not span_is_impossible:
-        #         answer_text = " ".join(tokens[start_position : (end_position + 1)])
-        #         logger.info("start_position: %d" % (start_position))
-        #         logger.info("end_position: %d" % (end_position))
-        #         logger.info("answer: %s" % (answer_text))
         feature = InputFeatures(
             unique_id=unique_id,
             example_index=example_index,
@@ -858,9 +835,6 @@ def write_predictions(
         null_score_diff_threshold,
 ):
     """Write final predictions to the json file and log-odds of null if needed."""
-    # logger.info("Writing predictions to: %s" % (output_prediction_file))
-    # logger.info("Writing nbest to: %s" % (output_nbest_file))
-
     example_index_to_features = collections.defaultdict(list)
     for feature in all_features:
         example_index_to_features[feature.example_index].append(feature)
@@ -1073,9 +1047,6 @@ def write_predictions_extended(
         "NbestPrediction", ["text", "start_log_prob", "end_log_prob"]
     )
 
-    # logger.info("Writing predictions to: %s", output_prediction_file)
-    # logger.info("Writing nbest to: %s" % (output_nbest_file))
-
     example_index_to_features = collections.defaultdict(list)
     for feature in all_features:
         example_index_to_features[feature.example_index].append(feature)
@@ -1789,9 +1760,7 @@ def get_final_text(pred_text, orig_text, do_lower_case, verbose_logging=False):
 
     if len(orig_ns_text) != len(tok_ns_text):
         if verbose_logging:
-            logger.info(
-                "Length not equal after stripping spaces: '%s' vs '%s'", orig_ns_text, tok_ns_text,
-            )
+            logger.info("Length not equal after stripping spaces: '%s' vs '%s'" % (orig_ns_text, tok_ns_text))
         return orig_text
 
     # We then project the characters in `pred_text` back to `orig_text` using
